#[non_exhaustive]pub enum Property {
Name(String),
Description(String),
Role(Role),
Parent(ObjectRefOwned),
TableCaption(String),
TableColumnDescription(String),
TableColumnHeader(String),
TableRowDescription(String),
TableRowHeader(String),
TableSummary(String),
HelpText(String),
Other((String, OwnedValue)),
}Expand description
Any accessibility related property on an crate::ObjectRef.
This is used only in the PropertyChangeEvent; this event gets triggered if a role or accessible
description of an item changes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Name(String)
Name of the element; this can either be the text of a simple UI element like a crate::Role::Button, but it could also be alternative text via aria-label.
Description(String)
The extended description of an item (usually via aria-describedby).
Role(Role)
The ARIA role of a given item.
Parent(ObjectRefOwned)
Parent of the item in a hierarchical tree.
TableCaption(String)
A description of the table as a whole: in HTML this is achieved via the
<table><caption>VALUE_HERE</caption>...</table> pattern
TableColumnDescription(String)
Similar to Self::TableColumnHeader except it’s the attached description instead of the
data in the header.
TableColumnHeader(String)
A column header: in HTML this is accomplished with the use of <th> in an aligned column with a given <td> cell element
TableRowDescription(String)
Similar to Self::TableRowHeader except it’s the attached description instead of the
data in the header.
TableRowHeader(String)
Row header: in HTML this is accomplished with the use of <th scope="row"> at the beginning of a <tr>
TableSummary(String)
The table summary is a shorter description of the table. In HTML this would be accomplished with the figure/figcaption pattern
HelpText(String)
The attached help text of the item.
Other((String, OwnedValue))
Any other attribute not explicitly laid out above.