pub struct SelectionChangedEvent {
pub item: ObjectRefOwned,
}Expand description
The selection of this item has changed.
For example: when a selection from a series of checkboxes is changed, this will change the state of the child, and cause a SelectionChangedEvent on the parent.
Fields
item: ObjectRefOwnedThe crate::ObjectRef which the event applies to.