pub struct TextCaretMovedEvent {
pub item: ObjectRefOwned,
pub position: i32,
}Expand description
The caret of the user also known as a cursor (not to be confused with mouse pointer) has changed position.
Fields
item: ObjectRefOwnedThe object on which the caret has been moved on.
position: i32New position of the caret.
NOTE: this provide the Unicode index (not the byte index) and therefore when referencing
locations in a string, you should be using the std::str::Chars iterator, and not use
anything like str::get (as this uses the byte index).
See also: TextChangedEvent.